@@ -1,20 +1,23 @@
 nested <- function(web, method="binmatnest2", rescale=FALSE, normalised=TRUE){
   # a wrapper function to call any of the currently implemented measures of nestedness
-  
-#  \item{method}{One or more of the following: discrepancy, discrepancy2, binmatnest, binmatnest2, NODF, NODF2, C.score, checker, wine, ALL}
-# \item{rescale}{Should the methods all be transformed, so that higher values mean higher nesting? Only in combination with method "ALL". Defaults to FALSE.}
-#  \item{...}{Arguments passed on the respective method.}
-
+ 
   if (! any(method %in% c("binmatnest", "discrepancy", "binmatnest2", "discrepancy2", "NODF", "NODF2", "weighted NODF", "wine", "C.score", "checker", "ALL"))) stop("Typo? Unknown method!")
   if ("ALL" %in% method) index <- c("binmatnest", "discrepancy", "binmatnest2", "discrepancy2", "NODF", "NODF2", "weighted NODF", "wine", "C.score", "checker") else index <- method
 
   out <- NULL
-  if ("binmatnest2" %in% index) out <- c(out, "binmatnest2"=nestedtemp(web)$statistic)
+	if ("binmatnest2" %in% index){ 
+		nessy <- try(nestedtemp(web)$statistic, silent=TRUE)
+		nessy.value <- if (inherits(nessy, "try-error")) NA else nessy
+		out <- c(out, binmatnest2 = nessy.value)
+	} 
 
-  if ("binmatnest" %in% index) out <- c(out, "binmatnest"=nestedness(web, null.models=FALSE)$temperature)
+	if ("binmatnest" %in% index){ # NA occur if web is full (i.e. no 0s)
+		nessy <- try(nestedness(web, null.models = FALSE)$temperature, silent=TRUE)
+		nessy.value <- if (inherits(nessy, "try-error")) NA else nessy
+		out <- c(out, binmatnest = nessy.value)
+	}
   
   if ("discrepancy2" %in% index) {
-  	#require(vegan) # not nice, this; it's a namespace issue; somehow permute::allPerms is not available to nesteddisc, forcing me to load all of vegan here!
   	out <- c(out, "discrepancy2"=nesteddisc(web)$statistic)
   	}
 
@@ -29,7 +32,7 @@ nested <- function(web, method="binmatnest2", rescale=FALSE, normalised=TRUE){
 
   if ("NODF" %in% index) out <- c(out, "NODF"=unname(nestednodf(web, order=FALSE)$statistic[3])) # the "original", as I had implemented it, too (in NODF)
 
-  if ("weighted NODF" %in% index) out <- c(out, "weighted NODF"=unname(nestednodf(web, order=FALSE, weighted=TRUE)$statistic[3]))
+  if ("weighted NODF" %in% index) out <- c(out, "weighted NODF"=unname(nestednodf(web, order=TRUE, weighted=TRUE)$statistic[3]))
 	
   if ("wine" %in% index) out <- c(out, "wine"=wine(web)$wine)
   
